@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
- * god-drawing-ms.h - 
+/*
+ * god-drawing-ms.h -
  * Copyright (C) 2003-2004, Christopher James Lahey
  *
  * Authors:
@@ -34,7 +34,7 @@
 
 #define d(x) x
 
-#define CVS_VERSION "$Id: god-drawing-ms.c 2295 2008-12-14 21:58:11Z mortenw $"
+#define CVS_VERSION "$Id$"
 #define ERROR_STRING(cond,str) G_STRLOC "\n<" CVS_VERSION ">\n" str " (" #cond ")"
 #define ERROR(cond,str) { \
 	if (!(cond)) { \
@@ -299,11 +299,11 @@ typedef enum
 					/*
 typedef enum
    {
-   msoanchorTop, 
-   msoanchorMiddle, 
-   msoanchorBottom, 
-   msoanchorTopCentered, 
-   msoanchorMiddleCentered, 
+   msoanchorTop,
+   msoanchorMiddle,
+   msoanchorBottom,
+   msoanchorTopCentered,
+   msoanchorMiddleCentered,
    msoanchorBottomCentered,
    msoanchorTopBaseline,
    msoanchorBottomBaseline,
@@ -312,7 +312,7 @@ typedef enum
    } MSOANCHOR;
 					*/
 					break;
- 
+
 				case 260:
 					god_property_table_set_int
 						(parse_state->prop_table,
@@ -542,7 +542,7 @@ end_container (GSList *stack, GsfInput *input, GError **err, gpointer user_data)
 		{
 			ShapeParseState *parse_state = STACK_TOP->parse_state;
 			GodShape *shape;
-			shape = g_object_new (GOD_SHAPE_TYPE, NULL);
+			shape = g_object_new (GOD_TYPE_SHAPE, NULL);
 			if (parse_state->prop_table) {
 				god_shape_set_prop_table (shape, parse_state->prop_table);
 				g_object_unref (parse_state->prop_table);
@@ -575,7 +575,7 @@ end_container (GSList *stack, GsfInput *input, GError **err, gpointer user_data)
 			ERROR (parse_state->main_shape != NULL, "Children Error");
 			parse_state->shapes = g_list_reverse (parse_state->shapes);
 			for (list = parse_state->shapes; list; list = list->next) {
-				god_shape_append_child (parse_state->main_shape, 
+				god_shape_append_child (parse_state->main_shape,
 							       list->data);
 				g_object_unref (list->data);
 			}
