@@ -216,7 +216,8 @@ gog_histogram_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 enum {
 	HISTOGRAM_PROP_0,
 	HISTOGRAM_PROP_VERTICAL,
-	HISTOGRAM_PROP_CUMULATIVE
+	HISTOGRAM_PROP_CUMULATIVE,
+	HISTOGRAM_PROP_BEFORE_GRID
 };
 
 static void
@@ -231,6 +232,9 @@ gog_histogram_plot_get_property (GObject *obj, guint param_id,
 	case HISTOGRAM_PROP_CUMULATIVE:
 		g_value_set_boolean (value, model->cumulative);
 		break;
+	case HISTOGRAM_PROP_BEFORE_GRID:
+		g_value_set_boolean (value, GOG_PLOT (obj)->rendering_order == GOG_PLOT_RENDERING_BEFORE_GRID);
+		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
@@ -257,6 +261,12 @@ gog_histogram_plot_set_property (GObject *obj, guint param_id,
 			gog_object_request_update (GOG_OBJECT (model));
 		}	
 		break;
+	case HISTOGRAM_PROP_BEFORE_GRID:
+		GOG_PLOT (obj)->rendering_order = (g_value_get_boolean (value))?
+						GOG_PLOT_RENDERING_BEFORE_GRID:
+						GOG_PLOT_RENDERING_LAST;
+		gog_object_emit_changed (GOG_OBJECT (obj), FALSE);
+		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 return; /* NOTE : RETURN */
@@ -286,6 +296,12 @@ cumulative_changed_cb (GtkToggleButton *btn, GogHistogramPlot *model)
 	}	
 }
 
+static void
+display_before_grid_cb (GtkToggleButton *btn, GObject *obj)
+{
+	g_object_set (obj, "before-grid", gtk_toggle_button_get_active (btn), NULL);
+}
+
 static void
 gog_histogram_plot_populate_editor (GogObject *item,
 			      GOEditor *editor,
@@ -309,6 +325,13 @@ gog_histogram_plot_populate_editor (GogObject *item,
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), hist->cumulative);
 		g_signal_connect (w, "toggled", G_CALLBACK (cumulative_changed_cb), hist);
 
+		w = go_gtk_builder_get_widget (gui, "before-grid");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
+				(GOG_PLOT (item))->rendering_order == GOG_PLOT_RENDERING_BEFORE_GRID);
+		g_signal_connect (G_OBJECT (w),
+			"toggled",
+			G_CALLBACK (display_before_grid_cb), item);
+
 		w = go_gtk_builder_get_widget (gui, "histogram-prefs");
 		go_editor_add_page (editor, w , _("Properties"));
 		g_object_unref (gui);
@@ -349,6 +372,12 @@ gog_histogram_plot_class_init (GogPlotClass *gog_plot_klass)
 			_("Use cumulated data"), 
 			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, HISTOGRAM_PROP_BEFORE_GRID,
+		g_param_spec_boolean ("before-grid",
+			_("Displayed under the grids"),
+			_("Should the plot be displayed before the grids"),
+			FALSE,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	gog_object_klass->type_name	= gog_histogram_plot_type_name;
 	gog_object_klass->view_type	= gog_histogram_plot_view_get_type ();
@@ -379,7 +408,7 @@ gog_histogram_plot_init (GogHistogramPlot *hist)
 {
 	GogPlot *plot = GOG_PLOT (hist);
 
-	plot->render_before_axes = TRUE;
+	plot->rendering_order = GOG_PLOT_RENDERING_BEFORE_AXIS;
 	hist->vertical = TRUE;
 }
 
@@ -979,13 +1008,12 @@ gog_histogram_plot_series_update (GogObject *obj)
 		if (x_len > 1) {
 			series->real_y = g_new0 (double, x_len - 1);
 			for (i = 0; i < y_len && y[i] <= series->real_x[0]; i++);
-			for (max = 1;  i < y_len; i++)
+			for (max = 1; i < y_len; i++)
 				if (go_finite (y[i])) {
-					while (y[i] > series->real_x[max]) {
+					while (max < x_len - 1 && y[i] > series->real_x[max])
 						max++;
-						if (max == x_len - 1)
-							break;
-					}
+					if (y[i] >  series->real_x[max])
+						break;
 					series->real_y[max-1]++;
 			}
 			if (y__len > 0) {
